@@ -1,4 +1,4 @@
-// $Id: AppData.h,v 1.94 1998/06/13 16:29:04 zeller Exp $ -*- C++ -*-
+// $Id: AppData.h,v 1.125 1998/11/27 19:46:26 zeller Exp $ -*- C++ -*-
 // DDD application data
 
 // Copyright (C) 1996-1998 Technische Universitaet Braunschweig, Germany.
@@ -40,7 +40,9 @@
 // The DDD application class name
 #define DDD_CLASS_NAME           Ddd_NAME
 
-// For a documentation of these resources, see `Ddd.in'.
+// For a documentation of these resources, see the `Ddd' app-resource
+// file or its original source, `Ddd.in.m4'.
+
 #define XtNsession               "session"
 #define XtNinitialSession        "initialSession"
 #ifndef XtCSessionID
@@ -50,8 +52,14 @@
 #define XtCDebugger              "Debugger"
 #define XtNdebuggerCommand       "debuggerCommand"
 #define XtCDebuggerCommand       "DebuggerCommand"
+#define XtNautoDebugger          "autoDebugger"
+#define XtCAutoDebugger          "AutoDebugger"
+#define XtNopenSelection         "openSelection"
+#define XtCOpenSelection         "OpenSelection"
 #define XtNtrace                 "trace"
 #define XtCTrace                 "Trace"
+#define XtNplayLog               "playLog"
+#define XtCPlayLog               "PlayLog"
 #define XtNgdbInitCommands       "gdbInitCommands"
 #define XtNgdbSettings           "gdbSettings"
 #define XtNdbxInitCommands       "dbxInitCommands"
@@ -60,6 +68,10 @@
 #define XtNxdbSettings           "xdbSettings"
 #define XtNjdbInitCommands       "jdbInitCommands"
 #define XtNjdbSettings           "jdbSettings"
+#define XtNpydbInitCommands      "pydbInitCommands"
+#define XtNpydbSettings          "pydbSettings"
+#define XtNperlInitCommands      "perlInitCommands"
+#define XtNperlSettings          "perlSettings"
 #define XtNrestartCommands       "restartCommands"
 #define XtCInitCommands          "InitCommands"
 #define XtNsourceInitCommands    "sourceInitCommands"
@@ -90,6 +102,7 @@
 #define XtCLinesAboveCursor      "LinesAboveCursor"
 #define XtNlinesBelowCursor      "linesBelowCursor"
 #define XtCLinesBelowCursor      "LinesBelowCursor"
+#define XtNindentScript          "indentScript"
 #define XtNindentSource          "indentSource"
 #define XtNindentCode            "indentCode"
 #define XtCIndent                "Indent"
@@ -99,7 +112,12 @@
 #define XtCSourceEditing         "SourceEditing"
 #define XtNlineBufferedConsole   "lineBufferredConsole"
 #define XtCLineBuffered          "LineBuffered"
-#define XtNdisplayShortcuts      "displayShortcuts"
+#define XtNgdbDisplayShortcuts   "gdbDisplayShortcuts"
+#define XtNdbxDisplayShortcuts   "dbxDisplayShortcuts"
+#define XtNxdbDisplayShortcuts   "xdbDisplayShortcuts"
+#define XtNjdbDisplayShortcuts   "jdbDisplayShortcuts"
+#define XtNpydbDisplayShortcuts  "pydbDisplayShortcuts"
+#define XtNperlDisplayShortcuts  "perlDisplayShortcuts"
 #define XtCDisplayShortcuts      "DisplayShortcuts"
 #define XtNconsoleButtons        "consoleButtons"
 #define XtNsourceButtons         "sourceButtons"
@@ -121,6 +139,21 @@
 #ifndef XtCWindow
 #define XtCWindow                "Window"
 #endif
+#define XtNautoCloseDataWindow   "autoCloseDataWindow"
+#define XtCAutoClose             "AutoClose"
+#define XtNplotCommand           "plotCommand"
+#define XtCPlotCommand           "PlotCommand"
+#define XtNplotTermType          "plotTermType"
+#define XtCPlotTermType          "PlotTermType"
+#define XtNplotInitCommands      "plotInitCommands"
+#define XtCPlotInitCommands      "PlotInitCommands"
+#define XtNplot2dSettings        "plot2dSettings"
+#define XtNplot3dSettings        "plot3dSettings"
+#define XtCPlotSettings          "PlotSettings"
+#define XtNplotWindowClass       "plotWindowClass"
+#define XtCPlotWindowClass       "PlotWindowClass"
+#define XtNplotWindowDelay       "plotWindowDelay"
+#define XtCWindowDelay           "WindowDelay"
 #define XtNtermCommand           "termCommand"
 #define XtCTermCommand           "TermCommand"
 #define XtNtermType              "termType"
@@ -133,6 +166,8 @@
 #define XtCSynchronousDebugger   "SynchronousDebugger"
 #define XtNterminateOnEOF        "terminateOnEOF"
 #define XtCTerminateOnEOF        "TerminateOnEOF"
+#define XtNpollChildStatus       "pollChildStatus"
+#define XtCPollChildStatus       "PollChildStatus"
 #define XtNdebuggerHost          "debuggerHost"
 #define XtCDebuggerHost          "DebuggerHost"
 #define XtNdebuggerRHost         "debuggerRHost"
@@ -143,6 +178,8 @@
 #define XtCRHostInitCommands     "RHostInitCommands"
 #define XtNrshCommand            "rshCommand"
 #define XtCRshCommand            "RshCommand"
+#define XtNfilterFiles           "filterFiles"
+#define XtCFilterFiles           "FilterFiles"
 #define XtNlistExecCommand       "listExecCommand"
 #define XtCListExecCommand       "ListExecCommand"
 #define XtNlistSourceCommand     "listSourceCommand"
@@ -173,9 +210,6 @@
 #define XtCShowNews              "ShowNews"
 #define XtNshowFonts             "showFonts"
 #define XtCShowFonts             "ShowFonts"
-#define XtNroulette              "roulette"
-#define XtNrussianRoulette       "russianRoulette"
-#define XtCRoulette              "Roulette"
 #define XtNcheckConfiguration    "checkConfiguration"
 #define XtCCheckConfiguration    "CheckConfiguration"
 #define XtNprintCommand          "printCommand"
@@ -208,6 +242,10 @@
 #define XtCCacheMachineCode      "CacheMachineCode"
 #define XtNsuppressWarnings      "suppressWarnings"
 #define XtCSuppressWarnings      "SuppressWarnings"
+#define XtNwarnIfLocked          "warnIfLocked"
+#define XtCWarnIfLocked          "WarnIfLocked"
+#define XtNcheckOptions          "checkOptions"
+#define XtCCheckOptions          "CheckOptions"
 #define XtNttyMode               "ttyMode"
 #define XtNfullNameMode          "fullNameMode"
 #define XtCTTYMode               "TTYMode"
@@ -272,6 +310,8 @@
 #define XtCGrabAction            "GrabAction"
 #define XtNdetectAliases         "detectAliases"
 #define XtCDetectAliases         "DetectAliases"
+#define XtNtypedAliases          "typedAliases"
+#define XtCTypedAliases          "TypedAliases"
 #define XtNdeleteAliasDisplays   "deleteAliasDisplays"
 #define XtCDeleteAliasDisplays   "DeleteAliasDisplays"
 #define XtNalign2dArrays         "align2dArrays"
@@ -282,14 +322,22 @@
 #define XtCBumpDisplays          "BumpDisplays"
 #define XtNhideInactiveDisplays  "hideInactiveDisplays"
 #define XtCHideInactiveDisplays  "HideInactiveDisplays"
+#define XtNshowBaseDisplayTitles "showBaseDisplayTitles"
+#define XtNshowDependentDisplayTitles "showDependentDisplayTitles"
+#define XtCShowDisplayTitles     "ShowDisplayTitles"
+#define XtNclusterDisplays       "clusterDisplays"
+#define XtCClusterDisplays       "ClusterDisplays"
 #define XtNstatusHistorySize     "statusHistorySize"
-#define XtCStatusHistorySize     "StatusHistorySize"
+#define XtCHistorySize           "HistorySize"
+#define XtNpopdownHistorySize    "popsownHistorySize"
+#define XtNsortPopdownHistory    "sortPopdownHistory"
+#define XtCSortPopdownHistory    "SortPopdownHistory"
 #define XtNverifyButtons         "verifyButtons"
 #define XtCVerifyButtons         "VerifyButtons"
 #define XtNautoRaiseTool         "autoRaiseTool"
 #define XtCAutoRaiseTool         "AutoRaiseTool"
 #define XtNdecorateTool          "decorateTool"
-#define XtCDecorateTool          "DecorateTool"
+#define XtCDecorate              "Decorate"
 #define XtNstickyTool            "stickyTool"
 #define XtCStickyTool            "StickyTool"
 #define XtNtoolRightOffset       "toolRightOffset"
@@ -307,6 +355,7 @@
 #define XtNflatDialogButtons     "flatDialogButtons"
 #define XtCFlatButtons           "FlatButtons"
 #define XtNbuttonColorKey        "buttonColorKey"
+#define XtNactiveButtonColorKey  "activeButtonColorKey"
 #define XtNsplashScreenColorKey  "splashScreenColorKey"
 #define XtCColorKey              "ColorKey"
 #define XtNautoCommands          "autoCommands"
@@ -321,7 +370,18 @@
 #define XtNcolorWMIcons          "colorWMIcons"
 #define XtCColorWMIcons          "ColorWMIcons"
 #define XtNcutCopyPasteBindings  "cutCopyPasteBindings"
+#define XtNselectAllBindings     "selectAllBindings"
 #define XtCBindingStyle          "BindingStyle"
+#define XtNmaxUndoDepth          "maxUndoDepth"
+#define XtCMaxUndoDepth          "MaxUndoDepth"
+#define XtNmaxUndoSize           "maxUndoSize"
+#define XtCMaxUndoSize           "MaxUndoSize"
+#define XtNdumpCore              "dumpCore"
+#define XtCDumpCore              "DumpCore"
+#define XtNdebugCoreDumps        "debugCoreDumps"
+#define XtCDebugCoreDumps        "DebugCoreDumps"
+#define XtNmaintenance       	 "maintenance"
+#define XtCMaintenance       	 "Maintenance"
 #define XtNlessTifVersion        "lessTifVersion"
 #define XtCLessTifVersion        "LessTifVersion"
 #define XtNdddinitVersion        "dddinitVersion"
@@ -333,7 +393,10 @@ struct AppData {
     String    initial_session;
     String    debugger;
     String    debugger_command;
+    Boolean   auto_debugger;
+    Boolean   open_selection;
     Boolean   trace;
+    String    play_log;
     String    gdb_init_commands;
     String    gdb_settings;
     String    dbx_init_commands;
@@ -342,6 +405,10 @@ struct AppData {
     String    xdb_settings;
     String    jdb_init_commands;
     String    jdb_settings;
+    String    pydb_init_commands;
+    String    pydb_settings;
+    String    perl_init_commands;
+    String    perl_settings;
     String    restart_commands;
     Boolean   source_init_commands;
     String    vsl_path;
@@ -359,11 +426,17 @@ struct AppData {
     Cardinal  lines_above_cursor;
     Cardinal  lines_below_cursor;
     Cardinal  indent_source;
+    Cardinal  indent_script;
     Cardinal  indent_code;
     Cardinal  line_number_width;
     Boolean   source_editing;
     Boolean   line_buffered_console;
-    String    display_shortcuts;
+    String    gdb_display_shortcuts;
+    String    dbx_display_shortcuts;
+    String    xdb_display_shortcuts;
+    String    jdb_display_shortcuts;
+    String    pydb_display_shortcuts;
+    String    perl_display_shortcuts;
     String    console_buttons;
     String    source_buttons;
     String    data_buttons;
@@ -377,17 +450,27 @@ struct AppData {
     Boolean   data_window;
     Boolean   source_window;
     Boolean   debugger_console;
+    Boolean   auto_close_data_window;
+    String    plot_command;
+    String    plot_term_type;
+    String    plot_window_class;
+    Cardinal  plot_window_delay;
+    String    plot_init_commands;
+    String    plot_2d_settings;
+    String    plot_3d_settings;
     String    term_command;
     String    term_type;
     Boolean   use_tty_command;
     int       question_timeout;
     Boolean   synchronous_gdb;
     Boolean   terminate_on_eof;
+    Boolean   poll_child_status;
     String    debugger_host;
     String    debugger_rhost;
     String    debugger_host_login;
     String    rhost_init_commands;
     String    rsh_command;
+    Boolean   filter_files;
     String    list_exec_command;
     String    list_source_command;
     String    list_core_command;
@@ -403,8 +486,6 @@ struct AppData {
     Boolean   show_license;
     Boolean   show_news;
     Boolean   show_fonts;
-    Boolean   roulette;
-    Boolean   russian_roulette;
     Boolean   check_configuration;
     String    print_command;
     String    paper_size;
@@ -421,6 +502,8 @@ struct AppData {
     Boolean   cache_source_files;
     Boolean   cache_machine_code;
     Boolean   suppress_warnings;
+    Boolean   warn_if_locked;
+    Cardinal  check_options;
     Boolean   tty_mode;
     OnOff     block_tty_input;
     Boolean   full_name_mode;
@@ -458,12 +541,18 @@ struct AppData {
     Cardinal  grab_action_delay;
     String    grab_action;
     Boolean   detect_aliases;
+    Boolean   typed_aliases;
     Boolean   delete_alias_displays;
     Boolean   align_2d_arrays;
     Boolean   expand_repeated_values;
     Boolean   bump_displays;
     Boolean   hide_inactive_displays;
+    Boolean   show_base_display_titles;
+    Boolean   show_dependent_display_titles;
+    Boolean   cluster_displays;
     Cardinal  status_history_size;
+    Cardinal  popdown_history_size;
+    Boolean   sort_popdown_history;
     Boolean   verify_buttons;
     Boolean   auto_raise_tool;
     OnOff     decorate_tool;
@@ -477,6 +566,7 @@ struct AppData {
     Boolean   flat_toolbar_buttons;
     Boolean   flat_dialog_buttons;
     String    button_color_key;
+    String    active_button_color_key;
     String    splash_screen_color_key;
     Boolean   auto_commands;
     String    auto_command_prefix;
@@ -485,6 +575,12 @@ struct AppData {
     Boolean   splash_screen;
     Boolean   color_wm_icons;
     BindingStyle cut_copy_paste_bindings;
+    BindingStyle select_all_bindings;
+    int       max_undo_depth;
+    int       max_undo_size;
+    Boolean   maintenance;
+    Boolean   dump_core;
+    Boolean   debug_core_dumps;
     int       lesstif_version;
     String    dddinit_version;
     String    app_defaults_version;
