@@ -1,4 +1,4 @@
-// $Id: BreakPoint.h,v 1.27 1998/06/14 12:54:27 zeller Exp $
+// $Id: BreakPoint.h,v 1.33 1998/11/24 09:54:41 zeller Exp $
 // Breakpoint handler
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -55,43 +55,45 @@ enum BPType {
 enum BPDispo {
     BPKEEP,			// Keep (default)
     BPDEL,			// Delete (temporary breakpoint)
-    BPDIS			// Disable (???)
+    BPDIS			// Disable (`enable once' in GDB)
 };
 
 class BreakPoint {
-    string  mynumber_str;
-    int     mynumber;
-    BPType  mytype;
-    BPDispo mydispo;
-    bool    myenabled;
-    string  myfile_name;
-    int     myline_nr;
-    string  myaddress;
-    string  myexpr;
-    string  myinfos;
-    int     myignore_count;
-    string  mycondition;
-    StringArray mycommands;
-    string  myarg;
-    WatchMode mywatch_mode;
-    bool    myenabled_changed;
-    bool    myfile_changed;
-    bool    myposition_changed;
-    bool    myaddress_changed;
-    bool    myselected;
-    Widget  mysource_glyph;
-    Widget  mycode_glyph;
+    int     mynumber;		// Breakpoint number
+    BPType  mytype;		// Type, as above
+    BPDispo mydispo;		// Disposition, as above
+    bool    myenabled;		// Is breakpoint enabled?
+    string  myfile_name;	// File name
+    int     myline_nr;		// Line number
+    string  myaddress;		// Address in memory
+    string  myfunc;		// Function name
+    string  myexpr;		// Expression to watch (for watchpoints)
+    string  myinfos;		// Additional information (human-readable)
+    int     myignore_count;	// Ignore count
+    string  mycondition;	// Breakpoint condition
+    StringArray mycommands;	// Commands to be issued when reached
+    string  myarg;		// Argument as given to breakpoint command
+    WatchMode mywatch_mode;	// Watchpoint detail
+
+    bool    myenabled_changed;	// True if `enabled' state changed
+    bool    myfile_changed;	// True if source file changed
+    bool    myposition_changed;	// True if position changed
+    bool    myaddress_changed;	// True if address changed
+    bool    myselected;		// True if selected
+
+    Widget  mysource_glyph;	// Associated glyph in source
+    Widget  mycode_glyph;	// Associated glyph in code
 
 private:
     BreakPoint(const BreakPoint& b)
-	: mynumber_str(b.mynumber_str),
-	  mynumber(b.mynumber),
+	: mynumber(b.mynumber),
 	  mytype(b.mytype),
 	  mydispo(b.mydispo),
 	  myenabled(b.myenabled),
 	  myfile_name(b.myfile_name),
 	  myline_nr(b.myline_nr),
 	  myaddress(b.myaddress),
+	  myfunc(b.myfunc),
 	  myexpr(b.myexpr),
 	  myinfos(b.myinfos),
 	  myignore_count(b.myignore_count),
@@ -120,14 +122,26 @@ protected:
     static string and_op();
     static bool is_false(const string& cond);
 
+    void process_gdb(string& info_output);
+    void process_dbx(string& info_output);
+    void process_xdb(string& info_output);
+    void process_jdb(string& info_output);
+    void process_pydb(string& info_output);
+    void process_perl(string& info_output);
+
 public:
     // Create new breakpoint from INFO_OUTPUT.  ARG denotes the
     // argument of a breakpoint setting command.  If NUMBER is given,
-    // assign this number.  Delete own info from INFO_OUTPUT.
-    BreakPoint (string& info_output, string arg = "", int number = 0);
+    // assign this number.  If FILE is given, assume this file.
+    // Delete own info from INFO_OUTPUT.
+    BreakPoint (string& info_output, char *arg = "",
+		int number = 0, char *file = "");
+
+    // This should avoid link warnings on SGI
+    // as reported by Mike Tosti <tosti@cinesite.com>
+    ~BreakPoint() {}
 
     // Breakpoint number.
-    const string& number_str() const { return mynumber_str; }
     int number() const               { return mynumber; }
 
     // Breakpoint symbol (`#N#', `?N?', or `_N_')
@@ -147,6 +161,7 @@ public:
     int line_nr() const             { return myline_nr; }
     const string& address() const   { return myaddress; }
     string pos() const;
+    const string& func() const      { return myfunc; }
 
     // Watchpoint info
     const string& expr() const   { return myexpr; }
@@ -183,13 +198,18 @@ public:
 
     // Update breakpoint from breakpoint info INFO_OUTPUT.  Return
     // true iff changes occurred.  Delete own info from INFO_OUTPUT.
-    bool update (string& info_output);
+    // UNDO_COMMANDS contains commands to undo the change.
+    // NEED_TOTAL_UNDO is set iff the change requires deleting and
+    // setting a new breakpoint.
+    bool update(string& info_output, ostream& undo_commands, 
+		bool& need_total_undo);
 
-    // Return commands to restore this breakpoint.  If AS_DUMMY is
-    // set, delete the breakpoint immediately in order to increase the
-    // breakpoint number.  If ADDR is set, use ADDR as (fake) address.
-    // If COND is set, use COND as (fake) condition.
-    bool get_state(ostream& os, int num, bool as_dummy = false, 
+    // Return commands to restore this breakpoint, using the dummy
+    // number NR.  If AS_DUMMY is set, delete the breakpoint
+    // immediately in order to increase the breakpoint number.  If
+    // ADDR is set, use ADDR as (fake) address.  If COND is set, use
+    // COND as (fake) condition.  Return true iff successful.
+    bool get_state(ostream& os, int nr, bool as_dummy = false, 
 		   string addr = "", string cond = char(-1));
 
     // Stuff for constructing `false' breakpoint conditions
