@@ -1,23 +1,23 @@
-// $Id: EntryType.h,v 1.4 1997/10/03 10:37:41 zeller Exp $ -*- C++ -*-
+// $Id: EntryType.h,v 1.7 1998/06/09 15:55:18 zeller Exp $ -*- C++ -*-
 // Entry types in `Settings' panel
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -43,9 +43,11 @@ enum EntryType
     NoNumToggleButtonEntry,	// Create 0/1 toggle button
     SensitiveToggleButtonEntry,	// Create sensitive/insensitive toggle button
     DisplayToggleButtonEntry,	// Create display toggle button
+    TargetOptionMenuEntry,	// Create `target' option menu
     CheckOptionMenuEntry,       // Create `check' option menu
     OtherOptionMenuEntry,       // Create other option menu
-    TextFieldEntry		// Create text field
+    TextFieldEntry,		// Create text field
+    SignalEntry		        // Create signal handler
 };
 
 typedef VarArray<EntryType> EntryTypeArray;
