@@ -1,4 +1,4 @@
-// $Id: GraphGC.h,v 1.15 1998/03/25 12:43:21 zeller Exp $
+// $Id: GraphGC.h,v 1.19 1998/10/05 12:21:08 zeller Exp $
 // Graph graphics context
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -37,6 +37,7 @@
 #include "BoxPoint.h"
 #include "Box.h"
 #include "TypeInfo.h"
+#include "explicit.h"
 
 // Where to attach edges
 enum EdgeAttachMode {
@@ -72,6 +73,7 @@ struct GraphGC {
     EdgeAttachMode edgeAttachMode;   // Where to attach edges
     bool           drawArrowHeads;   // Flag: draw arrow heads?
     bool           drawHints;        // Flag: draw hints?
+    bool	   drawAnnotations;  // Flag: draw annotations?
     BoxCoordinate  hintSize;         // Hint size (in pixels)
     unsigned       arrowAngle;       // Arrow angle (in degrees)
     unsigned       arrowLength;      // Arrow length (in pixels)
@@ -81,13 +83,21 @@ struct GraphGC {
     SelfEdgeDirection selfEdgeDirection; // Its direction
 
     // Printing stuff
-    BoxPrintGC     *printGC;               // Graphics context for printing
+    PrintGC     *printGC;               // Graphics context for printing
     bool        printSelectedNodesOnly; // Flag: print selected nodes only?
 
-    static BoxPostScriptGC defaultPrintGC;
+    unsigned short edge_red;	        // Colors to use for edges [0..65535]
+    unsigned short edge_green;
+    unsigned short edge_blue;
+
+    unsigned short node_red;	        // Colors to use for nodes [0..65535]
+    unsigned short node_green;
+    unsigned short node_blue;
+
+    static PostScriptPrintGC defaultPrintGC;
 
     // Default Constructor
-    GraphGC(GC n = 0, GC e = 0, GC i = 0, GC c = 0):
+    explicit GraphGC(GC n = 0, GC e = 0, GC i = 0, GC c = 0):
 	redraw(false),
         nodeGC(n),
         hintGC(n),
@@ -98,6 +108,7 @@ struct GraphGC {
 	edgeAttachMode(Straight),
         drawArrowHeads(true),
         drawHints(false),
+        drawAnnotations(true),
         hintSize(8),
         arrowAngle(30),
         arrowLength(10),
@@ -105,7 +116,13 @@ struct GraphGC {
 	selfEdgePosition(NorthEast),
 	selfEdgeDirection(Counterclockwise),
 	printGC(&defaultPrintGC),
-	printSelectedNodesOnly(false)
+	printSelectedNodesOnly(false),
+	edge_red(0),
+	edge_green(0),
+	edge_blue(0),
+	node_red(0),
+	node_green(0),
+	node_blue(0)
     {}
 
     // Copy Constructor
@@ -120,6 +137,7 @@ struct GraphGC {
 	edgeAttachMode(g.edgeAttachMode),
         drawArrowHeads(g.drawArrowHeads),
         drawHints(g.drawHints),
+        drawAnnotations(g.drawAnnotations),
         hintSize(g.hintSize),
         arrowAngle(g.arrowAngle),
         arrowLength(g.arrowLength),
@@ -127,7 +145,13 @@ struct GraphGC {
 	selfEdgePosition(g.selfEdgePosition),
 	selfEdgeDirection(g.selfEdgeDirection),
 	printGC(g.printGC),
-	printSelectedNodesOnly(g.printSelectedNodesOnly)
+	printSelectedNodesOnly(g.printSelectedNodesOnly),
+	edge_red(g.edge_red),
+	edge_green(g.edge_green),
+	edge_blue(g.edge_blue),
+	node_red(g.node_red),
+	node_green(g.node_green),
+	node_blue(g.node_blue)
     {}
 
     // Assignment
@@ -145,6 +169,7 @@ struct GraphGC {
 	    edgeAttachMode         = g.edgeAttachMode;
 	    drawArrowHeads         = g.drawArrowHeads;
 	    drawHints              = g.drawHints;
+	    drawAnnotations        = g.drawAnnotations;
 	    hintSize               = g.hintSize;
 	    arrowAngle             = g.arrowAngle;
 	    arrowLength            = g.arrowLength;
@@ -153,6 +178,12 @@ struct GraphGC {
 	    selfEdgeDirection      = g.selfEdgeDirection;
 	    printGC                = g.printGC;
 	    printSelectedNodesOnly = g.printSelectedNodesOnly;
+	    edge_red               = g.edge_red;
+	    edge_green             = g.edge_green;
+	    edge_blue              = g.edge_blue;
+	    node_red               = g.node_red;
+	    node_green             = g.node_green;
+	    node_blue              = g.node_blue;
 	}
 	return *this;
     }
