@@ -1,4 +1,4 @@
-// $Id: LiterateA.h,v 1.15 1998/03/25 12:43:37 zeller Exp $
+// $Id: LiterateA.h,v 1.16 1998/08/21 10:21:50 zeller Exp $
 // Agent interface on a callback basis
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
@@ -145,7 +145,7 @@ protected:
 
 public:
     // Constructor for Agent users
-    LiterateAgent(XtAppContext app_context, string pth,
+    LiterateAgent(XtAppContext app_context, const string& pth,
 		  unsigned nTypes = LiterateAgent_NTypes):
 	AsyncAgent(app_context, pth, nTypes), activeIO(false),
 	_block_tty_input(default_block_tty_input())
