@@ -1,4 +1,4 @@
-// $Id: MemCheck.h,v 1.6 1998/03/25 12:43:44 zeller Exp $ -*- C++ -*-
+// $Id: MemCheck.h,v 1.7 1998/09/21 19:12:57 zeller Exp $ -*- C++ -*-
 // Memory Checker
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -122,6 +122,9 @@ public:
     // If non-zero, log all alloc/free operations
     static int log;
 
+    // If non-zero, wipeout memory after being free'd
+    static int wipeout_free;
+
     // validate
     static int OK();
 };
