@@ -1,4 +1,4 @@
-// $Id: PosBuffer.h,v 1.23 1998/04/02 10:47:19 zeller Exp $
+// $Id: PosBuffer.h,v 1.25 1998/11/24 09:54:42 zeller Exp $
 // Filter position information from GDB output.
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -58,6 +58,14 @@ class PosBuffer {
 
     string auto_cmd_buffer;	// AutoCommand found
 
+protected:
+    void filter_gdb(string& answer);
+    void filter_dbx(string& answer);
+    void filter_xdb(string& answer);
+    void filter_jdb(string& answer);
+    void filter_pydb(string& answer);
+    void filter_perl(string& answer);
+
 public:
     bool check_pc;		// Whether to search for PC
     bool check_func;		// Whether to search for function name
@@ -97,6 +105,10 @@ public:
 	// clear();
     }
 
+    // This should avoid link warnings on SGI
+    // as reported by Mike Tosti <tosti@cinesite.com>
+    ~PosBuffer() {}
+
     // Filter positions from ANSWER and buffer them.  ANSWER contains
     // any remaining parts.
     void filter(string& answer);
