@@ -1,4 +1,4 @@
-// $Id: comm-manag.h,v 1.19 1998/06/09 06:03:08 zeller Exp $
+// $Id: comm-manag.h,v 1.24 1998/10/28 14:15:20 zeller Exp $
 // GDB communication manager.
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -46,15 +46,16 @@
 // Note: `Command.h' is the preferred way of interacting with GDB.
 
 // Call gdb->start() with required parameters
-void start_gdb ();
+void start_gdb(bool config = true);
 
 // Send user command CMD to GDB.  Invoke CALLBACK with DATA upon
-// completion.  If ECHO and VERBOSE are set, issue command in GDB
-// console.  If VERBOSE is set, issue answer in GDB console.  If
-// PROMPT is set, issue prompt.  If CHECK is set, add appropriate GDB
-// commands to get GDB state.
+// completion of CMD; invoke EXTRA_CALLBACK with DATA when all extra
+// commands (see CHECK) are done.  If ECHO and VERBOSE are set, issue
+// command in GDB console.  If VERBOSE is set, issue answer in GDB
+// console.  If PROMPT is set, issue prompt.  If CHECK is set, add
+// extra GDB commands to get GDB state.
 void send_gdb_command(string cmd, Widget origin,
-		      OQCProc callback, void *data,
+		      OQCProc callback, OACProc extra_callback, void *data,
 		      bool echo, bool verbose, bool prompt, bool check);
 
 // Send user input CMD to GDB (unchanged).
@@ -68,5 +69,15 @@ bool is_known_command(const string& answer);
 void init_session(const string& restart, const string& settings,
 		  bool try_source = false);
 
+// Let DDD handle COMMAND
+void internal_command(const string& command, OQCProc callback, void *data,
+		      bool echo, bool verbose, bool do_prompt);
+
+string internal_command(const string& command);
+bool is_internal_command(const string& command);
+
+// True if the debuggee is running
+extern bool debuggee_running;
+
 #endif // _DDD_comm_manag_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
