@@ -1053,12 +1053,7 @@
 "\n"
 "#pragma replace stdfontfamily\n"
 "stdfontfamily() = family_typewriter();\n"
-"\n"
-"\n"
-"shadow(box, thickness) =\n"
-"box & (square(thickness) | vrule(thickness))\n"
-"| square(thickness) & hrule(thickness);\n"
-"shadow(box) = shadow(box, 1);\n"
+"small(...) = rm(...);\n"
 "\n"
 "\n"
 "display_color(box) = color(box, \"black\", \"white\");\n"
@@ -1072,6 +1067,22 @@
 "array_color(box) = color(box, \"blue4\");\n"
 "reference_color(box) = color(box, \"blue4\");\n"
 "changed_color(box) = color(box, \"black\", \"#ffffcc\");\n"
+"shadow_color(box) = color(box, \"grey\");\n"
+"\n"
+"\n"
+"shadow(box, thickness) =\n"
+"box & (square(thickness) | shadow_color(vrule(thickness)))\n"
+"| square(thickness) & shadow_color(hrule(thickness));\n"
+"shadow(box) = shadow(box, 1);\n"
+"\n"
+"\n"
+"fixed_hlist(_) = hnull();\n"
+"fixed_hlist(_, head) = hfix(head);\n"
+"fixed_hlist(sep, head, ...) = hfix(head) & sep & fixed_hlist(sep, ...);\n"
+"\n"
+"fixed_vlist(_) = vnull();\n"
+"fixed_vlist(_, head) = vfix(head);\n"
+"fixed_vlist(sep, head, ...) = vfix(head) | sep | fixed_vlist(sep, ...);\n"
 "\n"
 "\n"
 "title (disp_nr, name) ->\n"
@@ -1080,6 +1091,10 @@
 "title_color(bf(name) & hfill());\n"
 "\n"
 "\n"
+"annotation (name) ->\n"
+"small(name);\n"
+"\n"
+"\n"
 "disabled () ->\n"
 "disabled_color(vcenter(it(\"(Disabled)\") & hfill()));\n"
 "\n"
@@ -1130,7 +1145,8 @@
 "\n"
 "\n"
 "horizontal_array (...) ->\n"
-"array_color(frame(indent(hlist((vwhite(3) & vrule() & vwhite(3)), ...))));\n"
+"array_color(frame(indent(fixed_hlist(vwhite() & vrule() & vwhite(), ...)))\n"
+"& hfill());\n"
 "\n"
 "\n"
 "twodim_array (...) ->\n"
@@ -1140,7 +1156,7 @@
 "\n"
 "\n"
 "struct_value (...) ->\n"
-"struct_color(frame(indent(valign(...)) & hfill()));\n"
+"struct_color(frame(indent(valign(...))));\n"
 "\n"
 "\n"
 "collapsed_struct_value () ->\n"
@@ -1155,13 +1171,13 @@
 "struct_color(rm(name));\n"
 "\n"
 "\n"
-"struct_member (name, value, name_width) ->\n"
+"struct_member (name, sep, value, name_width) ->\n"
 "vcenter(rm(name) | hspace(name_width))\n"
-"& vcenter(rm(\" = \")) & rm(value);\n"
+"& vcenter(rm(sep)) & rm(value);\n"
 "\n"
 "\n"
 "list_value (...) ->\n"
-"list_color(valign(...) & hfill());\n"
+"list_color(valign(...));\n"
 "\n"
 "\n"
 "collapsed_list_value () ->\n"
@@ -1176,9 +1192,17 @@
 "list_color(rm(name));\n"
 "\n"
 "\n"
-"list_member (name, value, name_width) ->\n"
+"list_member (name, sep, value, name_width) ->\n"
 "vcenter(rm(name) | hspace(name_width))\n"
-"& vcenter(rm(\" = \")) & rm(value) & hfill();\n"
+"& vcenter(rm(sep)) & rm(value) & hfill();\n"
+"\n"
+"\n"
+"sequence_value (...) ->\n"
+"simple_color(fixed_hlist(vwhite(), ...) & hfill());\n"
+"\n"
+"\n"
+"collapsed_sequence_value () ->\n"
+"collapsed_simple_value();\n"
 "\n"
 "\n"
 "reference_value (ref, value) ->\n"
@@ -1199,3 +1223,7 @@
 "\n"
 "display_box (title, value) ->\n"
 "shadow(display_color(frame(title | hrule() | hwhite () | rm(value))));\n"
+"\n"
+"\n"
+"display_box (value) ->\n"
+"shadow(display_color(frame(rm(value))));\n"
