@@ -1,4 +1,4 @@
-// $Id: getrlimit.h,v 1.3 1998/04/15 09:35:40 zeller Exp $ -*- C++ -*-
+// $Id: getrlimit.h,v 1.4 1998/11/12 23:51:11 zeller Exp $ -*- C++ -*-
 // getrlimit() decl
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -42,6 +42,7 @@
 #include <sys/time.h>		// SunOS wants this
 #endif // HAVE_SYS_TIME_H
 
+extern "C" {
 // Harry Mangalam <hjm@darwin.bio.uci.edu> says he had to comment out
 // the following line `on an Alpha PC164LX system running Linux kernel
 // ver 2.0.33 to get it to compile (otherwise a bunch of RLIMIT errors
@@ -49,11 +50,12 @@
 #include <sys/resource.h>
 
 #if HAVE_GETRLIMIT && !HAVE_GETRLIMIT_DECL
-extern "C" int getrlimit (int resource, struct rlimit *rlp);
+int getrlimit (int resource, struct rlimit *rlp);
 #endif // HAVE_GETRLIMIT && !HAVE_GETRLIMIT_DECL
 #if HAVE_SETRLIMIT && !HAVE_SETRLIMIT_DECL
-extern "C" int setrlimit (int resource, struct rlimit *rlp);
+int setrlimit (int resource, struct rlimit *rlp);
 #endif // HAVE_SETRLIMIT && !HAVE_SETRLIMIT_DECL
+}
 
 #endif // HAVE_SYS_RESOURCE_H
 #endif // HAVE_GETRLIMIT && HAVE_SETRLIMIT
