@@ -1,4 +1,4 @@
-// $Id: options.h,v 1.40 1998/05/21 17:37:22 zeller Exp $ -*- C++ -*-
+// $Id: options.h,v 1.55 1998/11/28 16:42:00 zeller Exp $ -*- C++ -*-
 // Save and edit DDD options
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -63,6 +63,11 @@ bool saving_options_excludes_data(unsigned long flags);
 // Save options in current session state file, using FLAGS
 bool save_options(unsigned long flags);
 
+// Get restarting commands in RESTART, using FLAGS
+bool get_restart_commands(string& restart, unsigned long flags);
+
+// Check options file
+void check_options_file();
 
 // Lots and lots of callbacks
 extern void sourceToggleFindWordsOnlyCB     (Widget, XtPointer, XtPointer);
@@ -84,6 +89,10 @@ extern void graphToggleShowHintsCB          (Widget, XtPointer, XtPointer);
 extern void graphToggleSnapToGridCB         (Widget, XtPointer, XtPointer);
 extern void graphToggleCompactLayoutCB      (Widget, XtPointer, XtPointer);
 extern void graphToggleAutoLayoutCB         (Widget, XtPointer, XtPointer);
+extern void graphToggleAutoCloseCB          (Widget, XtPointer, XtPointer);
+extern void graphToggleShowAnnotationsCB    (Widget, XtPointer, XtPointer);
+extern void graphToggleShowDependentTitlesCB(Widget, XtPointer, XtPointer);
+extern void graphToggleClusterDisplaysCB    (Widget, XtPointer, XtPointer);
 extern void graphSetGridSizeCB              (Widget, XtPointer, XtPointer);
 
 extern void dddToggleGroupIconifyCB         (Widget, XtPointer, XtPointer);
@@ -92,6 +101,7 @@ extern void dddToggleSeparateExecWindowCB   (Widget, XtPointer, XtPointer);
 extern void dddToggleCheckGrabsCB           (Widget, XtPointer, XtPointer);
 extern void dddToggleSaveHistoryOnExitCB    (Widget, XtPointer, XtPointer);
 extern void dddToggleSuppressWarningsCB     (Widget, XtPointer, XtPointer);
+extern void dddToggleWarnIfLockedCB         (Widget, XtPointer, XtPointer);
 
 extern void dddToggleButtonTipsCB           (Widget, XtPointer, XtPointer);
 extern void dddToggleValueTipsCB            (Widget, XtPointer, XtPointer);
@@ -102,6 +112,10 @@ extern void dddToggleButtonCaptionsCB       (Widget, XtPointer, XtPointer);
 extern void dddToggleButtonImagesCB         (Widget, XtPointer, XtPointer);
 extern void dddToggleFlatButtonsCB          (Widget, XtPointer, XtPointer);
 extern void dddToggleColorButtonsCB         (Widget, XtPointer, XtPointer);
+extern void dddToggleToolbarsAtBottomCB     (Widget, XtPointer, XtPointer);
+
+extern void dddSetCrashCB                   (Widget, XtPointer, XtPointer);
+extern void dddClearMaintenanceCB           (Widget, XtPointer, XtPointer);
 
 extern void dddSetGlobalTabCompletionCB     (Widget, XtPointer, XtPointer);
 extern void dddSetSeparateWindowsCB         (Widget, XtPointer, XtPointer);
@@ -110,14 +124,21 @@ extern void dddSetToolBarCB                 (Widget, XtPointer, XtPointer);
 extern void dddSetKeyboardFocusPolicyCB     (Widget, XtPointer, XtPointer);
 extern void dddSetPannerCB                  (Widget, XtPointer, XtPointer);
 extern void dddSetDebuggerCB                (Widget, XtPointer, XtPointer);
-extern void dddSetBindingStyleCB            (Widget, XtPointer, XtPointer);
+extern void dddToggleAutoDebuggerCB         (Widget, XtPointer, XtPointer);
+extern void dddSetCutCopyPasteBindingsCB    (Widget, XtPointer, XtPointer);
+extern void dddSetSelectAllBindingsCB       (Widget, XtPointer, XtPointer);
+
+extern void dddSetUndoBufferSizeCB          (Widget, XtPointer, XtPointer);
+extern void dddClearUndoBufferCB            (Widget, XtPointer, XtPointer);
 
 extern void dddSetEditCommandCB             (Widget, XtPointer, XtPointer);
+extern void dddSetPlotCommandCB             (Widget, XtPointer, XtPointer);
 extern void dddSetGetCoreCommandCB          (Widget, XtPointer, XtPointer);
 extern void dddSetPSCommandCB               (Widget, XtPointer, XtPointer);
 extern void dddSetTermCommandCB             (Widget, XtPointer, XtPointer);
 extern void dddSetUncompressCommandCB       (Widget, XtPointer, XtPointer);
 extern void dddSetWWWCommandCB              (Widget, XtPointer, XtPointer);
+extern void dddSetBuiltinPlotWindowCB       (Widget, XtPointer, XtPointer);
 
 extern void DDDSaveOptionsCB                (Widget, XtPointer, XtPointer);
 extern void DDDSaveOptionsAsCB              (Widget, XtPointer, XtPointer);
