@@ -1,4 +1,4 @@
-// $Id: value-read.h,v 1.18 1998/05/12 14:37:15 zeller Exp $
+// $Id: value-read.h,v 1.23 1998/09/17 14:59:44 zeller Exp $
 // Read variable values in string representation
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -39,25 +39,12 @@
 
 #include "strclass.h"
 #include "bool.h"
+#include "DispValueT.h"
+
 #include <iostream.h>
 
-// Various types of elements that can be read
-enum DispValueType {
-    UnknownType = 0,		// Unknown type
-    Simple = 1,			// Ordinary or other value
-    Pointer,			// Pointer value
-    Array,			// Array
-    StructOrClass,		// Struct, Class, Record, Object
-    BaseClass,			// C++ base class member
-    Reference,			// C++ Reference.  2 children.
-    List,			// List of values.  Last member may be text,
-    Text			// Multi-line text.  Last member of a list.
-};
-
-ostream& operator<<(ostream& os, DispValueType type);
-
 // Determine type of next element in VALUE
-DispValueType determine_type (string value);
+DispValueType determine_type (const string& value);
 
 // Read single token from VALUE
 string read_token (string& value);
@@ -71,16 +58,18 @@ string read_pointer_value (string& value, bool ignore_repeats);
 // Read array; return false iff error
 bool read_array_begin (string& value, string& addr);
 bool read_array_next (string& value);
-bool read_array_end (string& value);
+void read_array_end(string& value);
 
 // Read `<repeats N times>'; return N (1 if no repeat)
 int read_repeats(string& value);
 
 // Read struct or class; return false iff error
-bool read_str_or_cl_begin (string& value, string& addr);
-bool read_str_or_cl_next (string& value);
-bool read_str_or_cl_end (string& value);
-bool read_members_of_xy (string& value);
+bool read_struct_begin (string& value, string& addr);
+bool read_struct_next (string& value);
+void read_struct_end(string& value);
+
+// Read GDB `members of CLASS:' prefix
+bool read_members_prefix (string& value);
 
 // Convert a DBX initial `dump' line into a readable format
 void munch_dump_line (string& value);
@@ -97,5 +86,11 @@ bool is_BaseClass_name (const string& name);
 // Cut off basename part (e.g. "foo.<Base>" becomes "foo")
 void cut_BaseClass_name (string& full_name);
 
+// True if VALUE starts with `END', `}', or likewise
+bool is_ending(const string& value);
+
+// True if VALUE is ending or starts with `,', `;', or likewise
+bool is_delimited(const string& value);
+
 #endif // _DDD_value_read_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
